pub fn classify_git_trust_reply(doc: &TrustTask<Value>) -> Option<WriteOutcome>Expand description
Classify the reply to a git-trust/grant or git-trust/revoke write.
None when doc is not a reply to this family.
pub fn classify_git_trust_reply(doc: &TrustTask<Value>) -> Option<WriteOutcome>Classify the reply to a git-trust/grant or git-trust/revoke write.
None when doc is not a reply to this family.